@@ -9,16 +9,10 @@ import javax.management.MalformedObjectNameException;
  * @author roland
  * @since Jun 30, 2009
  */
-public class OperationChecking implements OperationCheckingMBean, MBeanRegistration {
-
-    private String name;
+public class OperationChecking implements OperationCheckingMBean,MBeanRegistration {
 
     private int counter = 0;
 
-    public OperationChecking(String pName) {
-        name = pName;
-    }
-
     public void reset() {
         counter = 0;
     }
@@ -31,14 +25,23 @@ public class OperationChecking implements OperationCheckingMBean, MBeanRegistrat
         }
     }
 
-    public ObjectName preRegister(MBeanServer pMBeanServer, ObjectName pObjectName) throws MalformedObjectNameException {
-        return new ObjectName(name);
+    public int overloadedMethod(String arg) {
+        return 1;
     }
 
-    public void postRegister(Boolean pBoolean) {
+    public int overloadedMethod(String arg, int arg2) {
+        return 2;
     }
 
-    public void preDeregister()  {
+    public ObjectName preRegister(MBeanServer server, ObjectName name) throws Exception {
+        return new ObjectName("jmx4perl.it:type=operation");
+
+    }
+
+    public void postRegister(Boolean registrationDone) {
+    }
+
+    public void preDeregister() throws Exception {
     }
 
     public void postDeregister() {
