@@ -2,6 +2,8 @@
 package JMX::Jmx4Perl::Product::Weblogic;
 
 use JMX::Jmx4Perl::Product::BaseHandler;
+use JMX::Jmx4Perl::Request;
+use Data::Dumper;
 use strict;
 use base "JMX::Jmx4Perl::Product::BaseHandler";
 
@@ -13,8 +15,8 @@ JMX::Jmx4Perl::Product::Weblogic - Handler for Oracle WebLogic
 
 =head1 DESCRIPTION
 
-This is the product handler support for Oracle Weblogic Server 10 (9 might
-work, but is not tested) (L<http://www.oracle.com/appserver/>)
+This is the product handler support for Oracle Weblogic Server 9 and 10 
+(L<http://www.oracle.com/appserver/>)
 
 =cut
 
@@ -32,27 +34,36 @@ sub order {
 
 sub _try_version {
     my $self = shift;
-    
     my $is_weblogic = $self->_try_server_domain;
     return undef unless $is_weblogic;
     return $self->try_attribute("version",$self->{server_domain},"ConfigurationVersion");
 }
 
+sub vendor {
+    return "Oracle";
+}
+
 sub server_info { 
     my $self = shift;
     my $ret = $self->SUPER::server_info();
     $ret .= sprintf("%-10.10s %s\n","IP:",$self->{jmx4perl}->get_attribute("SERVER_ADDRESS"));
 }
+
 sub _try_server_domain {
     my $self = shift;
     return $self->try_attribute
       ("server_domain",
        "com.bea:Name=RuntimeService,Type=weblogic.management.mbeanservers.runtime.RuntimeServiceMBean",
-       "DomainConfiguration");
+       "DomainConfiguration",
+       "canonicalName");
 }
 
 sub jsr77 {
-    return 1;
+    return 0;
+}
+
+sub autodetect_pattern {
+    return ("version",1);
 }
 
 sub init_aliases {
@@ -72,12 +83,24 @@ sub init_aliases {
      operations => {
                     # Needs to be done in a more complex. Depends on admin server name *and*
                     # JVM used
-                    THREAD_DUMP => [ "com.bea:Name=examplesServer,ServerRuntime=examplesServer,Type=JRockitRuntime", "ThreadStackDump"]
+                    THREAD_DUMP => \&exec_thread_dump
                    }
      # Alias => [ "mbean", "attribute", "path" ]
     };
 }
 
+sub exec_thread_dump {
+    my $self = shift;
+    my $jmx = $self->{jmx4perl};
+
+    my $beans = $jmx->search("com.bea:Type=JRockitRuntime,*");
+    if ($beans && @{$beans}) {
+        my $bean = $beans->[0];
+        my $request = new JMX::Jmx4Perl::Request(READ,$bean,"ThreadStackDump");
+        return $jmx->request($request);
+    }
+    die $self->name,": Cannot execute THREAD_DUMP because I can't find a suitable JRockitRuntime";
+}
 
 =head1 LICENSE
 
