@@ -85,13 +85,32 @@ separator. This looks a bit like a simplified form of XPath.
 
 =item max_depth, max_objects, max_list_size
 
-With these objects you can restrict the size of the JSON structure
+With these number you can restrict the size of the JSON structure
 returned. C<max_depth> gives the maximum nesting level of the JSON
 object,C<max_objects> returns the maximum number of objects to be returned in
 total and C<max_list_size> restrict the number of all arrays and collections
 (maps, lists) in the answer. Note, that you should use this restrictions if you
 are doing massive bulk operations.
 
+=item target
+
+If given, the request is processed by the agent in proxy mode, i.e. it will
+proxy to another server exposing via a JSR-160 connector. C<target> is a hash
+which contains information how to reach the target service via the proxy. This
+hash knows the following keys:
+
+=over 
+
+=item url
+
+JMX service URL as specified in JSR-160 pointing to the target server. 
+
+=item env
+
+Further context information which is another hash.
+
+=back
+
 =back 
 
 =head1 METHODS
@@ -143,6 +162,18 @@ For the options C<max_depth>, C<max_objects> and C<max_list_size>, you can mix
 them in into the hashref if using the hashed argument format. For the first
 format, these options are given as a final hashref.
 
+If the request should be proxied through this request, a target configuration
+needs to be given as optional parameter. The target configuration consists of a
+JMX service C<url> and a optional environment, which is given as a key-value
+map. For example
+
+ $req = new JMX::Jmx4Perl::Request(..., { 
+                                     target => { 
+                                                  url => "",
+                                                  env => { ..... }
+                                                }
+                                     } );
+
 Note, depending on the type, some parameters are mandatory. The mandatory
 parameters and the order of the arguments for the constructor variant without
 named parameters are:
@@ -248,7 +279,7 @@ sub _validate {
     my $self = shift;
     if ($self->{type} eq READ ||  $self->{type} eq WRITE) {
         die $self->{type} . ": No mbean name given\n",Dumper($self) unless $self->{mbean};
-        die $self->{type} . ": No attribute name given\n" unless $self->{attribute};
+        die $self->{type} . ": No attribute name but path is given\n" if (!$self->{attribute} && $self->{path});
     }
     if ($self->{type} eq WRITE) {
         die $self->{type} . ": No value given\n" unless $self->{value};
@@ -265,7 +296,7 @@ sub TO_JSON {
     my $ret = {
                type => $self->{type} ? uc($self->{type}) : undef,
               };
-    for my $k (qw(mbean attribute path value operation arguments max_depth max_objects max_list_size)) {
+    for my $k (qw(mbean attribute path value operation arguments max_depth max_objects max_list_size target)) {
         $ret->{$k} = $self->{$k} if $self->{$k};
     }
     return $ret;
